<?php

namespace WilokeShowcaseBenefits\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;

class WilokeShowcaseBenefitsStyle2 extends Widget_Base
{

	public function get_name()
	{
		return 'wiloke-showcase-benefits-style2';
	}

	public function get_title()
	{
		return esc_html__('Wiloke Showcase Benefits Style 2', 'wiloke-showcase-benefits');
	}

	public function get_icon()
	{
		return 'eicon-posts-ticker';
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Content', 'wiloke-showcase-benefits'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'   => esc_html__('Heading', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('Heading', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'heading_tag',
			[
				'label'   => esc_html__('Heading Tag', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h3',
			]
		);

		$this->add_control(
			'description',
			[
				'label'   => esc_html__('Description', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => esc_html__('Your description here', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__('Choose Image', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$oLeftRepeater = new Repeater();

		$oLeftRepeater->add_control(
			'icon',
			[
				'label' => esc_html__('Icon', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::ICONS,
			]
		);

		$oLeftRepeater->add_control(
			'item_title',
			[
				'label'   => esc_html__('Item Title', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'wiloke-showcase-benefits'),
			]
		);

		$oLeftRepeater->add_control(
			'item_description',
			[
				'label'   => esc_html__('Item Description', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Description', 'wiloke-showcase-benefits'),
			]
		);

		$oLeftRepeater->add_control(
			'item_image',
			[
				'label'       => esc_html__('Item Image', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::MEDIA,
				'description' => esc_html__('Upload a square image. Recommended size: 500px by 500px.',
					'wiloke-showcase-benefits'),
				'default'     => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'left_items_list',
			[
				'label'       => esc_html__('Right Benefits Items', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $oLeftRepeater->get_controls(),
				'title_field' => '{{{ item_title }}}',
			]
		);

		$oRightRepeater = new Repeater();

		$oRightRepeater->add_control(
			'icon',
			[
				'label' => esc_html__('Icon', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::ICONS,
			]
		);

		$oRightRepeater->add_control(
			'item_title',
			[
				'label'   => esc_html__('Item Title', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'wiloke-showcase-benefits'),
			]
		);

		$oRightRepeater->add_control(
			'item_description',
			[
				'label'   => esc_html__('Item Description', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Description', 'wiloke-showcase-benefits'),
			]
		);

		$oRightRepeater->add_control(
			'item_image',
			[
				'label'       => esc_html__('Item Image', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::MEDIA,
				'description' => esc_html__('Upload a square image. Recommended size: 500px by 500px.',
					'wiloke-showcase-benefits'),
				'default'     => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'right_items_list',
			[
				'label'       => esc_html__('Right Benefits Items', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $oRightRepeater->get_controls(),
				'title_field' => '{{{ item_title }}}',
			]
		);

		// View More Button Name
		$this->add_control(
			'view_more_button_name',
			[
				'label'   => esc_html__('Button Name', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('View More', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'view_more_button_link',
			[
				'label' => esc_html__('Button Link', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::URL
			]
		);

// View More Button Icon
		$this->add_control(
			'view_more_button_icon',
			[
				'label' => esc_html__('Button Icon', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::ICONS,
			]
		);

// View More Button Color
		$this->add_control(
			'view_more_button_color',
			[
				'label'     => esc_html__('Button Text Color', 'wiloke-showcase-benefits'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .view-more-button' => 'color: {{VALUE}};',
				],
			]
		);

// View More Button Background Color
		$this->add_control(
			'view_more_button_background_color',
			[
				'label'     => esc_html__('Button Background Color', 'wiloke-showcase-benefits'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .view-more-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'view_more_button_text_align',
			[
				'label'   => esc_html__('Button Text Alignment', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'left'   => esc_html__('Left', 'wiloke-showcase-benefits'),
					'center' => esc_html__('Center', 'wiloke-showcase-benefits'),
					'right'  => esc_html__('Right', 'wiloke-showcase-benefits'),
				],
				'default' => 'center',
			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		?>
		<div class="wil-sb">
			<div class="wil-container">
				<div class="wil-row">
					<?php
					include WILOKE_SHOWCASE_BENEFITS_PATH . 'src/Widgets/Partials/HeadingAndDescription.php';
					include WILOKE_SHOWCASE_BENEFITS_PATH . 'src/Widgets/Partials/ShowcaseBenefitsStyle2.php';
					include WILOKE_SHOWCASE_BENEFITS_PATH . 'src/Widgets/Partials/ViewMoreBtn.php';
					?>
				</div>
			</div>
		</div>
		<?php
	}

	public function get_style_depends()
	{
		// Enqueue specific style for this widget
		return [WILOKE_SHOWCASE_BENEFITS_ID . '-style'];
	}
}
