<?php

namespace WilokeShowcaseBenefits\Widgets;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;

class WilokeShowcaseBenefitsStyle3 extends Widget_Base
{

	public function get_name()
	{
		return 'wiloke-showcase-benefits-style3';
	}

	public function get_title()
	{
		return esc_html__('Wiloke Showcase Benefits Style 3', 'wiloke-showcase-benefits');
	}

	public function get_icon()
	{
		return 'eicon-posts-ticker';
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__('Content', 'wiloke-showcase-benefits'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'   => esc_html__('Heading', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('Heading', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'heading_tag',
			[
				'label'   => esc_html__('Heading Tag', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h3',
			]
		);

		$this->add_control(
			'description',
			[
				'label'   => esc_html__('Description', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => esc_html__('Your description here', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__('Choose Image', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'icon',
			[
				'label' => esc_html__('Icon', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::ICONS,
			]
		);

		$repeater->add_control(
			'item_description',
			[
				'label'   => esc_html__('Item Description', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Description', 'wiloke-showcase-benefits'),
			]
		);

		$repeater->add_control(
			'item_image',
			[
				'label'       => esc_html__('Item Image', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::MEDIA,
				'description' => esc_html__('Upload a square image. Recommended size: 500px by 500px.',
					'wiloke-showcase-benefits'),
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'items_list',
			[
				'label'       => esc_html__('Benefits Items', 'wiloke-showcase-benefits'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'title_field' => '{{{ item_title }}}',
			]
		);


		// View More Button Name
		$this->add_control(
			'view_more_button_name',
			[
				'label'   => esc_html__('Button Name', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__('View More', 'wiloke-showcase-benefits'),
			]
		);

		$this->add_control(
			'view_more_button_link',
			[
				'label' => esc_html__('Button Link', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::URL
			]
		);

// View More Button Icon
		$this->add_control(
			'view_more_button_icon',
			[
				'label' => esc_html__('Button Icon', 'wiloke-showcase-benefits'),
				'type'  => Controls_Manager::ICONS,
			]
		);

// View More Button Color
		$this->add_control(
			'view_more_button_color',
			[
				'label'     => esc_html__('Button Text Color', 'wiloke-showcase-benefits'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .view-more-button' => 'color: {{VALUE}};',
				],
			]
		);

// View More Button Background Color
		$this->add_control(
			'view_more_button_background_color',
			[
				'label'     => esc_html__('Button Background Color', 'wiloke-showcase-benefits'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .view-more-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'view_more_button_text_align',
			[
				'label'   => esc_html__('Button Text Alignment', 'wiloke-showcase-benefits'),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'left'   => esc_html__('Left', 'wiloke-showcase-benefits'),
					'center' => esc_html__('Center', 'wiloke-showcase-benefits'),
					'right'  => esc_html__('Right', 'wiloke-showcase-benefits'),
				],
				'default' => 'center',
			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		?>
		<div class="wil-sb">
			<div class="wil-container">
				<div class="wil-sb-container">
					<div
						class="wil-sb-image-container"
						style="--wil-sb-aspect-ratio: 90; width: 50%"
					>
						<div>
							<?php
							if (!empty($settings['image']['id'])) {
								$image_html = wp_get_attachment_image(
									$settings['image']['id'],
									'large', // or specify a custom image size
									false,
									[
										'loading' => 'lazy',
										'class'   => 'wil-sb-image__img',
										'alt'     => esc_attr(get_post_meta($settings['image']['id'], '_wp_attachment_image_alt', true))
									]
								);

								if (!empty($image_html)) {
									echo $image_html;
								}
							}
							?>
						</div>
					</div>

					<div
						class="wil-sb-wrapper w:50% d:flex fld:column flxs:0 w:100%!@+md jc:center" Style="width:50%"
					>
						<div class="wil-row">
							<div
								class="wil-col-xs-0 wil-col-sm-0 wil-col-md-0 wil-col-lg-0"
							>
								<div class="wil-sb-content">
									<?php if (!empty($settings['heading'])): ?>
									<<?php echo esc_attr($settings['heading_tag']); ?> class="wil-sb-heading__title">
									<?php echo esc_html($settings['heading']); ?>
								</<?php echo esc_attr($settings['heading_tag']); ?>>
								<?php endif; ?>
								<?php if (!empty($settings['description'])): ?>
									<div class="wil-sb-heading__text">
										<p><?php echo wp_kses_post($settings['description']); ?></p>
									</div>
								<?php endif; ?>
								<?php
								include WILOKE_SHOWCASE_BENEFITS_PATH . 'src/Widgets/Partials/ShowcaseBenefitsStyle3.php';
								include WILOKE_SHOWCASE_BENEFITS_PATH . 'src/Widgets/Partials/ViewMoreBtn.php';
								?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	public function get_style_depends()
	{
		// Enqueue specific style for this widget
		return [WILOKE_SHOWCASE_BENEFITS_ID . '-style'];
	}
}
